@@ -465,7 +465,7 @@ create_animation (AboutState *state)
 		permutation[ui] = ui;
 
 	for (ui = 0; ui < N; ui++) {
-		unsigned pui = (int)(random_01 () * N);
+		unsigned pui = gnm_random_uniform_int (N);
 		unsigned A = permutation[ui];
 		permutation[ui] = permutation[pui];
 		permutation[pui] = A;
@@ -588,7 +588,7 @@ dialog_about (WBCGtk *wbcg)
 			  "version", GNM_VERSION_FULL,
 			  "website", PACKAGE_URL,
 			  "website-label", _("Visit the Gnumeric website"),
-			  "logo-icon-name", "gnumeric",
+			  "logo-icon-name", "org.gnumeric.gnumeric",
 			  "copyright", _("Copyright \xc2\xa9 1998-2020"),
 			  "comments", _("Free, Fast, Accurate - Pick Any Three!"),
 			  "license", _(LICENSE_TEXT),
