@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * dialog-analysis-tool-kaplan-meier.c:
  *
@@ -18,16 +17,15 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
 #include <gnumeric.h>
-#include "dialogs.h"
-#include "analysis-kaplan-meier.h"
-#include "analysis-tools.h"
+#include <dialogs/dialogs.h>
+#include <tools/analysis-kaplan-meier.h>
+#include <tools/analysis-tools.h>
 
 #include <workbook.h>
 #include <workbook-control.h>
@@ -36,8 +34,8 @@
 #include <gui-util.h>
 #include <parse-util.h>
 #include <gnm-format.h>
-#include <tool-dialogs.h>
-#include <dao-gui-utils.h>
+#include <dialogs/tool-dialogs.h>
+#include <dialogs/dao-gui-utils.h>
 #include <sheet.h>
 #include <expr.h>
 #include <number-match.h>
@@ -45,18 +43,17 @@
 #include <selection.h>
 #include <value.h>
 #include <commands.h>
-#include "help.h"
+#include <dialogs/help.h>
 
 #include <widgets/gnm-dao.h>
-#include <widgets/gnumeric-expr-entry.h>
+#include <widgets/gnm-expr-entry.h>
 
 #include <string.h>
-#include <gtk/gtk.h>
 
 #define KAPLAN_MEIER_KEY      "analysistools-kaplan-meier-dialog"
 
 typedef struct {
-	GenericToolState base;
+	GnmGenericToolState base;
 	GtkWidget *censorship_button;
 	GtkWidget *censor_spin_from;
 	GtkWidget *censor_spin_to;
@@ -250,7 +247,7 @@ kaplan_meier_tool_ok_clicked_cb (G_GNUC_UNUSED GtkWidget *button,
 	analysis_tools_data_kaplan_meier_t  *data;
 
 	data = g_new0 (analysis_tools_data_kaplan_meier_t, 1);
-	dao  = parse_output ((GenericToolState *)state, NULL);
+	dao  = parse_output ((GnmGenericToolState *)state, NULL);
 
 
 	data->base.wbc = GNM_WBC (state->base.wbcg);
@@ -623,7 +620,7 @@ dialog_kaplan_meier_tool (WBCGtk *wbcg, Sheet *sheet)
 
 	if (dialog_tool_init (&state->base, wbcg, sheet,
 			      GNUMERIC_HELP_LINK_KAPLAN_MEIER,
-			      "kaplan-meier.ui", "KaplanMeier",
+			      "res:ui/kaplan-meier.ui", "KaplanMeier",
 			      _("Could not create the Kaplan Meier Tool dialog."),
 			      KAPLAN_MEIER_KEY,
 			      G_CALLBACK (kaplan_meier_tool_ok_clicked_cb), NULL,
@@ -737,7 +734,7 @@ dialog_kaplan_meier_tool (WBCGtk *wbcg, Sheet *sheet)
 	gnm_dao_set_put (GNM_DAO (state->base.gdao), TRUE, TRUE);
 	kaplan_meier_tool_update_sensitivity_cb (NULL, state);
 	kaplan_meier_tool_update_groups_sensitivity_cb (NULL, state);
-	tool_load_selection ((GenericToolState *)state, TRUE);
+	tool_load_selection ((GnmGenericToolState *)state, TRUE);
 
 	gtk_widget_show_all (GTK_WIDGET (state->base.dialog));
 	/* And to hide the in-place button again */
