@@ -1,5 +1,4 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/**
+/*
  * dialog-autofilter.c:  A pair of dialogs for autofilter conditions
  *
  * (c) Copyright 2002 Jody Goldberg <jody@gnome.org>
@@ -23,8 +22,8 @@
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
 #include <gnumeric.h>
-#include "dialogs.h"
-#include "help.h"
+#include <dialogs/dialogs.h>
+#include <dialogs/help.h>
 
 #include <gui-util.h>
 #include <commands.h>
@@ -39,7 +38,6 @@
 #include <number-match.h>
 #include <undo.h>
 
-#include <gtk/gtk.h>
 #include <string.h>
 
 typedef struct {
@@ -371,7 +369,7 @@ dialog_auto_filter_expression (WBCGtk *wbcg,
 	if (gnm_dialog_raise_if_exists
 	    (wbcg, DIALOG_KEY_EXPRESSION))
 		return;
-	gui = gnm_gtk_builder_load ("autofilter-expression.ui",
+	gui = gnm_gtk_builder_load ("res:ui/autofilter-expression.ui",
 				   NULL, GO_CMD_CONTEXT (wbcg));
 	if (gui == NULL)
 		return;
@@ -471,7 +469,7 @@ dialog_auto_filter (WBCGtk *wbcg,
 
 	if (gnm_dialog_raise_if_exists (wbcg, DIALOG_KEY))
 		return;
-	gui = gnm_gtk_builder_load ("autofilter-top10.ui",
+	gui = gnm_gtk_builder_load ("res:ui/autofilter-top10.ui",
 				   NULL, GO_CMD_CONTEXT (wbcg));
 	if (gui == NULL)
 		return;
