@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * dialog-fill-series.c: Fill according to a linear or exponential serie.
  *
@@ -19,15 +18,14 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
 #include <gnumeric.h>
-#include "dialogs.h"
-#include "help.h"
-#include "tool-dialogs.h"
+#include <dialogs/dialogs.h>
+#include <dialogs/help.h>
+#include <dialogs/tool-dialogs.h>
 
 #include <gui-util.h>
 #include <selection.h>
@@ -45,15 +43,14 @@
 #include <cell.h>
 #include <widgets/gnm-dao.h>
 
-#include <dao-gui-utils.h>
+#include <dialogs/dao-gui-utils.h>
 
-#include <gtk/gtk.h>
-#include "fill-series.h"
+#include <tools/fill-series.h>
 
 #define FILL_SERIES_KEY "fill-series-dialog"
 
 typedef struct {
-	GenericToolState base;
+	GnmGenericToolState base;
 	GtkWidget          *start_entry;
 	GtkWidget          *stop_entry;
 	GtkWidget          *step_entry;
@@ -93,7 +90,7 @@ cb_fill_series_ok_clicked (G_GNUC_UNUSED GtkWidget *button,
 	data_analysis_output_t  *dao;
 
 	fs = g_new0 (fill_series_t, 1);
-	dao  = parse_output ((GenericToolState *)state, NULL);
+	dao  = parse_output ((GnmGenericToolState *)state, NULL);
 
 	/* Read the `Series in' radio buttons. */
 	radio = go_gtk_builder_get_widget (state->base.gui, "series_in_rows");
@@ -117,7 +114,7 @@ cb_fill_series_ok_clicked (G_GNUC_UNUSED GtkWidget *button,
 	entry_to_float (GTK_ENTRY (state->start_entry),
 			&fs->start_value, TRUE);
 
-	if (!cmd_analysis_tool (WORKBOOK_CONTROL (state->base.wbcg),
+	if (!cmd_analysis_tool (GNM_WBC (state->base.wbcg),
 				state->base.sheet,
 				dao, fs, fill_series_engine, TRUE))
 		gtk_widget_destroy (state->base.dialog);
@@ -236,21 +233,21 @@ void
 dialog_fill_series (WBCGtk *wbcg)
 {
 	FillSeriesState *state;
-	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
+	WorkbookControl *wbc = GNM_WBC (wbcg);
 	SheetView       *sv = wb_control_cur_sheet_view (wbc);
 
 	g_return_if_fail (wbcg != NULL);
 
 	/* Only pop up one copy per workbook */
-	if (gnumeric_dialog_raise_if_exists (wbcg, FILL_SERIES_KEY)) {
+	if (gnm_dialog_raise_if_exists (wbcg, FILL_SERIES_KEY)) {
 		return;
 	}
 
 	state = g_new (FillSeriesState, 1);
 
-	if (dialog_tool_init ((GenericToolState *)state, wbcg, sv_sheet (sv),
+	if (dialog_tool_init ((GnmGenericToolState *)state, wbcg, sv_sheet (sv),
 			      GNUMERIC_HELP_LINK_FILL_SERIES,
-			      "fill-series.ui", "Fill_series",
+			      "res:ui/fill-series.ui", "Fill_series",
 			      _("Could not create the Fill Series dialog."),
 			      FILL_SERIES_KEY,
 			      G_CALLBACK (cb_fill_series_ok_clicked), NULL,
