@@ -216,7 +216,7 @@ cb_dialog_apply_clicked (G_GNUC_UNUSED GtkWidget *button,
 	}
 
 
-	format = gnm_style_get_format (gnm_cell_get_style (state->set_cell));
+	format = gnm_cell_get_format (state->set_cell);
 	if (entry_to_float_with_format (GTK_ENTRY(state->to_value_entry),
 					&state->target_value, TRUE, format)){
 		go_gtk_notice_nonmodal_dialog (GTK_WINDOW(state->dialog),
@@ -228,7 +228,7 @@ cb_dialog_apply_clicked (G_GNUC_UNUSED GtkWidget *button,
 		return;
 	}
 
-	format = gnm_style_get_format (gnm_cell_get_style (state->change_cell));
+	format = gnm_cell_get_format (state->change_cell);
 	if (entry_to_float_with_format (GTK_ENTRY(state->at_least_entry),
 					 &state->xmin, TRUE, format)) {
 		state->xmin = -max_range_val;
