@@ -1,5 +1,4 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/**
+/*
  * dialog-scenarios.c:  Create, edit, and view scenarios.
  *
  * Author:
@@ -18,14 +17,13 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
 #include <gnumeric.h>
-#include "dialogs.h"
-#include "help.h"
+#include <dialogs/dialogs.h>
+#include <dialogs/help.h>
 
 #include <gui-util.h>
 #include <commands.h>
@@ -33,15 +31,15 @@
 #include <workbook.h>
 #include <wbc-gtk.h>
 #include <sheet.h>
-#include <dao-gui-utils.h>
+#include <dialogs/dao-gui-utils.h>
 #include <position.h>
 #include <ranges.h>
 #include <value.h>
 #include <cell.h>
-#include <dao.h>
-#include "scenarios.h"
+#include <tools/dao.h>
+#include <tools/scenarios.h>
+#include <dialogs/tool-dialogs.h>
 
-#include <gtk/gtk.h>
 #include <goffice/goffice.h>
 #include <string.h>
 
@@ -49,7 +47,7 @@
 #define LIGHT_GRAY GO_COLOR_GREY(199)   /* "gray78" */
 
 typedef struct {
-	GenericToolState base;
+	GnmGenericToolState base;
 
 	GtkWidget  *show_button;
 	GtkWidget  *delete_button;
@@ -273,7 +271,7 @@ check_name (const gchar *n)
 }
 
 /**
- * scenarios_ok_clicked_cb:
+ * scenario_add_ok_clicked_cb:
  * @button:
  * @state:
  *
@@ -340,7 +338,7 @@ scenario_add_ok_clicked_cb (G_GNUC_UNUSED GtkWidget *button,
 	dao_init_new_sheet (&dao);
 	dao.sheet = state->base.sheet;
 
-	wbc = WORKBOOK_CONTROL (state->base.wbcg);
+	wbc = GNM_WBC (state->base.wbcg);
 
 	sc = gnm_sheet_scenario_new (state->base.sheet, name);
 	if (comment && comment[0])
@@ -383,17 +381,17 @@ dialog_scenario_add (WBCGtk *wbcg)
 	if (wbcg == NULL)
 		return;
 
-	wbc = WORKBOOK_CONTROL (wbcg);
+	wbc = GNM_WBC (wbcg);
 
 	/* Only pop up one copy per workbook */
-	if (gnumeric_dialog_raise_if_exists (wbcg, "ScenarioAdd"))
+	if (gnm_dialog_raise_if_exists (wbcg, "ScenarioAdd"))
 		return;
 
 	state = g_new (ScenariosState, 1);
 
 	if (dialog_tool_init (&state->base, wbcg, wb_control_cur_sheet (wbc),
 			      GNUMERIC_HELP_LINK_SCENARIOS_ADD,
-			      "scenario-add.ui", "ScenarioAdd",
+			      "res:ui/scenario-add.ui", "ScenarioAdd",
 			      error_str,
 			      "ScenarioAdd",
 			      G_CALLBACK (scenario_add_ok_clicked_cb), NULL,
@@ -425,10 +423,10 @@ dialog_scenario_add (WBCGtk *wbcg)
 					   wbcg,
 					   GNM_DIALOG_DESTROY_SHEET_REMOVED);
 
-	gnumeric_editable_enters (GTK_WINDOW (state->base.dialog),
+	gnm_editable_enters (GTK_WINDOW (state->base.dialog),
 				  GTK_WIDGET (state->name_entry));
 	scenario_add_update_sensitivity_cb (NULL, state);
-	tool_load_selection ((GenericToolState *)state, TRUE);
+	tool_load_selection ((GnmGenericToolState *)state, TRUE);
 }
 
 
@@ -563,7 +561,7 @@ scenarios_ok_clicked_cb (G_GNUC_UNUSED GtkWidget *button,
 			 ScenariosState *state)
 {
 	if (state->current) {
-		WorkbookControl *wbc = WORKBOOK_CONTROL (state->base.wbcg);
+		WorkbookControl *wbc = GNM_WBC (state->base.wbcg);
 		cmd_scenario_mngr (wbc, state->current, state->undo);
 	}
 
@@ -606,7 +604,7 @@ scenarios_cancel_clicked_cb (G_GNUC_UNUSED GtkWidget *button,
 
 	restore_old_values (state);
 
-	wbc = WORKBOOK_CONTROL (state->base.wbcg);
+	wbc = GNM_WBC (state->base.wbcg);
 
 	/* Remove report sheets created on this dialog session. */
 	for (cur = state->new_report_sheets; cur != NULL;
@@ -718,7 +716,7 @@ scenarios_summary_clicked_cb (G_GNUC_UNUSED GtkWidget *button,
 		return;
 	}
 
-	scenario_summary (WORKBOOK_CONTROL (state->base.wbcg), state->base.sheet,
+	scenario_summary (GNM_WBC (state->base.wbcg), state->base.sheet,
 			  results, &new_sheet);
 
 	state->new_report_sheets =
@@ -783,7 +781,7 @@ dialog_scenarios (WBCGtk *wbcg)
 
 	g_return_if_fail (wbcg != NULL);
 
-	wbc   = WORKBOOK_CONTROL (wbcg);
+	wbc   = GNM_WBC (wbcg);
 	sheet = wb_control_cur_sheet (wbc);
 
 	state = g_new (ScenariosState, 1);
@@ -794,7 +792,7 @@ dialog_scenarios (WBCGtk *wbcg)
 
 	if (dialog_tool_init (&state->base, wbcg, sheet,
 			      GNUMERIC_HELP_LINK_SCENARIOS_VIEW,
-			      "scenario-manager.ui", "Scenarios",
+			      "res:ui/scenario-manager.ui", "Scenarios",
 			      error_str, "Scenarios",
 			      G_CALLBACK (scenarios_ok_clicked_cb),
 			      G_CALLBACK (scenarios_cancel_clicked_cb),
