@@ -775,13 +775,12 @@ gnm_auto_fmt_filter_edges (GnmFT const *origft)
 {
 	GSList *ptr;
 	GnmFT *ft = gnm_ft_clone (origft);
-	GnmFTMember *member;
 	gboolean is_edge, l = FALSE, r = FALSE, t = FALSE, b = FALSE;
 
 	for (ptr = ft->members; ptr != NULL ; ) {
-		member = ptr->data;
+		GnmFTMember *member = ptr->data;
 		ptr = ptr->next;
-		if (!member->direction == FREQ_DIRECTION_NONE)
+		if (member->direction != FREQ_DIRECTION_NONE)
 			continue;
 
 		is_edge = FALSE;
@@ -937,7 +936,7 @@ cb_format_hash_style (GnmFT *ft, GnmRange *r, GnmStyle *mstyle, gpointer user)
 			key.col = col;
 			key.row = row;
 			g_hash_table_insert (table,
-					     g_memdup (&key, sizeof (key)),
+					     go_memdup (&key, sizeof (key)),
 					     gnm_style_dup (mstyle));
 		}
 
