@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * go-data-cache-source.h :
  *
@@ -22,7 +21,7 @@
 #ifndef GO_DATA_CACHE_SOURCE_H
 #define GO_DATA_CACHE_SOURCE_H
 
-#include "goffice-data.h"	/* remove after move to goffice */
+#include <goffice-data.h>	/* remove after move to goffice */
 #include <goffice/goffice.h>
 #include <glib-object.h>
 
