@@ -1086,3 +1086,28 @@ gnm_cpp (const char *src, GHashTable *vars)
 	g_string_free (ifdefs, TRUE);
 	return g_string_free (res, FALSE);
 }
+
+// Should we write the shortest representation of floating point values
+// in text-based formats (gnumeric/xlsx/ods)?
+//
+// This is currently off because
+// (1) There are test suite considerations.  Files currently written with
+//     fixed precision will not round-trip.  Presumably that can be sorted
+//     out.
+// (2) go_dtoa is not perfect.  We don't want to deal with (1) twice.
+//
+// Note: this does not change the semantics of the files.  The files mean
+// precisely the same thing, ie., the different strings are representations
+// of the same IEEE-754 number which is (generally) not a nice decimal
+// number with few decimals.
+//
+// ANYONE WHO FAILS TO UNDERSTAND THE PREVIOUS PARAGRAPH WILL BE SUMMARILY
+// IGNORED.
+gboolean
+gnm_shortest_rep_in_files (void)
+{
+	static int q = -1;
+	if (q == -1)
+		q = g_getenv ("GNM_SHORTREP_FILES") != NULL;
+	return q;
+}
