@@ -60,6 +60,7 @@ void gnm_hash_table_foreach_ordered (GHashTable *h,
 				     gpointer user);
 
 void gnm_xml_in_doc_dispose_on_exit (GsfXMLInDoc **pdoc);
+void gnm_xml_out_end_element_check (GsfXMLOut *xout, char const *id);
 
 Sheet *gnm_file_saver_get_sheet (GOFileSaver const *fs,
 				 WorkbookView const *wbv);
@@ -73,6 +74,10 @@ gboolean gnm_file_saver_common_export_option (GOFileSaver const *fs,
 					      const char *value,
 					      GError **err);
 
+char *gnm_cpp (const char *src, GHashTable *vars);
+
+gboolean gnm_shortest_rep_in_files(void);
+
 G_END_DECLS
 
 #endif /* _GNM_GUTILS_H_ */
