@@ -524,7 +524,7 @@ range_split_ranges (GnmRange const *hard, GnmRange const *soft)
 GnmRange *
 gnm_range_dup (GnmRange const *r)
 {
-	return g_memdup (r, sizeof (*r));
+	return go_memdup (r, sizeof (*r));
 }
 
 /**
@@ -1217,7 +1217,7 @@ global_range_list_parse (Sheet *sheet, char const *str)
  * @ep:
  * @flags:
  * @handler: (scope call):
- * @closure: user data.
+ * @closure: user data.
  *
  * Returns: (transfer none):
  **/
