@@ -70,7 +70,7 @@ gnm_coth (gnm_float x)
  */
 gnm_float
 gnm_acoth (gnm_float x)
-{	
+{
 	return (gnm_abs (x) > 2)
 		? gnm_log1p (2 / (x - 1)) / 2
 		: gnm_log ((x - 1) / (x + 1)) / -2;
@@ -79,12 +79,10 @@ gnm_acoth (gnm_float x)
 /* ------------------------------------------------------------------------- */
 
 
-#ifdef GNM_REDUCES_TRIG_RANGE
-
 static gnm_float
-reduce_pi_half_simple (gnm_float x, int *km4)
+reduce_pi_simple (gnm_float x, int *pk, int kbits)
 {
-	static const gnm_float two_over_pi = 0.63661977236758134307553505349;
+	static const gnm_float two_over_pi = GNM_const(0.63661977236758134307553505349);
 	static const gnm_float pi_over_two[] = {
 		+0x1.921fb5p+0,
 		+0x1.110b46p-26,
@@ -93,18 +91,18 @@ reduce_pi_half_simple (gnm_float x, int *km4)
 		+0x1.c1cd12p-107
 	};
 	int i;
-	gnm_float k = gnm_floor (x * two_over_pi + 0.5);
+	gnm_float k = gnm_floor (x * gnm_ldexp (two_over_pi, kbits - 2) + 0.5);
 	gnm_float xx = 0;
 
 	g_assert (k < (1 << 26));
-	*km4 = (int)k & 3;
+	*pk = (int)k;
 
 	if (k == 0)
 		return x;
 
-	x -= k * pi_over_two[0];
+	x -= k * gnm_ldexp (pi_over_two[0], 2 - kbits);
 	for (i = 1; i < 5; i++) {
-		gnm_float dx = k * pi_over_two[i];
+		gnm_float dx = k * gnm_ldexp (pi_over_two[i], 2 - kbits);
 		gnm_float s = x - dx;
 		xx += x - s - dx;
 		x = s;
@@ -140,10 +138,10 @@ add_at (guint32 *dst, guint64 p)
 }
 
 static gnm_float
-reduce_pi_half_full (gnm_float x, int *km4)
+reduce_pi_full (gnm_float x, int *pk, int kbits)
 {
 	/* FIXME?  This table isn't big enough for long double's range */
-	static guint32 one_over_two_pi[] = {
+	static const guint32 one_over_two_pi[] = {
 		0x28be60dbu,
 		0x9391054au,
 		0x7f09d5f4u,
@@ -181,7 +179,7 @@ reduce_pi_half_full (gnm_float x, int *km4)
 		0x9afed7ecu,
 		0x47e35742u
 	};
-	static guint32 pi_over_four[] = {
+	static const guint32 pi_over_four[] = {
 		0xc90fdaa2u,
 		0x2168c234u,
 		0xc4c6628bu,
@@ -229,21 +227,21 @@ reduce_pi_half_full (gnm_float x, int *km4)
 			add_at (&r[i + 1], (guint64)w2  * one_over_two_pi[i + 2 + di]);
 
 		/*
-		 * We're done at i==3 unless the first 29 bits, not counting
-		 * those ending up in sign and *km4, are all zeros or ones.
+		 * We're done at i==3 unless the first 31-kbits bits, not counting
+		 * those ending up in sign and *pk, are all zeros or ones.
 		 */
-		if (i == 3 && ((r[1] + 1u) & 0x1fffffffu) > 1)
+		if (i == 3 && ((r[1] + 1u) & (0x7fffffffu >> kbits)) > 1)
 			break;
 	}
 
-	*km4 = r[1] >> 30;
-	if ((neg = ((r[1] >> 29) & 1))) {
-		*km4 = (*km4 + 1) & 3;
+	*pk = kbits ? (r[1] >> (32 - kbits)) : 0;
+	if ((neg = ((r[1] >> (31 - kbits)) & 1))) {
+		(*pk)++;
 		/* Two-complement negation */
 		for (j = 1; j <= i; j++) r[j] ^= 0xffffffffu;
 		add_at (&r[i], 1);
 	}
-	r[1] &= 0x3fffffffu;
+	r[1] &= (0xffffffffu >> kbits);
 
 	j = 1;
 	if (r[j] == 0) j++;
@@ -256,9 +254,9 @@ reduce_pi_half_full (gnm_float x, int *km4)
 	add_at (&r4[3], (guint64)r[j + 2] * pi_over_four[0]);
 
 	h48 = gnm_ldexp (((guint64)r4[0] << 16) | (r4[1] >> 16),
-			 -32 * j + 3 - 16);
+			 -32 * j + (kbits + 1) - 16);
 	l48 = gnm_ldexp (((guint64)(r4[1] & 0xffff) << 32) | r4[2],
-			 -32 * j + 3 - 64);
+			 -32 * j + (kbits + 1) - 64);
 
 	rh = h48 + l48;
 	rl = h48 - rh + l48;
@@ -268,59 +266,67 @@ reduce_pi_half_full (gnm_float x, int *km4)
 		rl = -rl;
 	}
 
-	return rh + rl;
+	return gnm_ldexp (rh + rl, 2 - kbits);
 }
 
-/*
- * Subtract k times Pi from @x where k is picked such that the absolute
- * value of x-k*Pi is no larger than Pi/4.  k%4 is returned in @km4.
- * @x must not be negative.
- *
- * This function is used to reduce arguments to trigonometric functions
- * to [-Pi/4;+Pi/4], a range in which hardware and libm generally are
- * accurate.  This avoids problems for example with Intel chips for
- * values near multiples of Pi/2 or values above 10^15.
- *
- * Note, that the Pi used has sufficient accuracy to not suffer cancellation
- * errors throughout the entire range of "double".  That means 1000+ bits.
- *
- * The "no larger than Pi/4" condition may be violated by a hair.  That's
- * not important since none of the trigonometric functions are critical
- * there.
- */
-static gnm_float
-reduce_pi_half (gnm_float x, int *km4)
+/**
+  * gnm_reduce_pi:
+  * @x: number of reduce
+  * @e: scale between -1 and 8, inclusive.
+  * @k: (out): location to return lower @e+1 bits of reduction count
+  *
+  * This function performs range reduction for trigonometric functions.
+  *
+  * Returns: a value, xr, such that x = xr + j * Pi/2^@e for some integer
+  * number j and |xr| <=  Pi/2^(@e+1).  The lower @e+1 bits of j will be
+  * returned in @k.
+  */
+gnm_float
+gnm_reduce_pi (gnm_float x, int e, int *k)
 {
-	void *state;
 	gnm_float xr;
+	void *state;
 
-	if (gnm_isnan (x))
-		return x;
+	g_return_val_if_fail (e >= -1 && e <= 8, x);
+	g_return_val_if_fail (k != NULL, x);
 
-	g_assert (x >= 0);
+	if (!gnm_finite (x)) {
+		*k = 0;
+		return x * gnm_nan;
+	}
 
 	/*
 	 * We aren't actually using quads, but we rely somewhat on
 	 * proper ieee double semantics.
 	 */
 	state = gnm_quad_start ();
-	if (x < (1u << 26))
-		xr = reduce_pi_half_simple (x, km4);
+
+	if (gnm_abs (x) < (1u << (27 - e)))
+		xr = reduce_pi_simple (gnm_abs (x), k, e + 1);
 	else
-		xr = reduce_pi_half_full (x, km4);
+		xr = reduce_pi_full (gnm_abs (x), k, e + 1);
+
+	if (x < 0) {
+		xr = -xr;
+		*k = -*k;
+	}
+	*k &= ((1 << (e + 1)) - 1);
+
 	gnm_quad_end (state);
 
 	return xr;
 }
 
+
+
+
+#ifdef GNM_REDUCES_TRIG_RANGE
+
 gnm_float
 gnm_sin (gnm_float x)
 {
 	int km4;
-	gnm_float ax = gnm_abs (x);
-	gnm_float xr = reduce_pi_half (ax, &km4);
-
-	if (x < 0) km4 ^= 2;
+	gnm_float xr = gnm_reduce_pi (x, 1, &km4);
 
 	switch (km4) {
 	default:
@@ -335,8 +341,7 @@ gnm_float
 gnm_cos (gnm_float x)
 {
 	int km4;
-	gnm_float ax = gnm_abs (x);
-	gnm_float xr = reduce_pi_half (ax, &km4);
+	gnm_float xr = gnm_reduce_pi (x, 1, &km4);
 
 	switch (km4) {
 	default:
@@ -351,10 +356,7 @@ gnm_float
 gnm_tan (gnm_float x)
 {
 	int km4;
-	gnm_float ax = gnm_abs (x);
-	gnm_float xr = reduce_pi_half (ax, &km4);
-
-	if (x < 0) xr = -xr;
+	gnm_float xr = gnm_reduce_pi (x, 1, &km4);
 
 	switch (km4) {
 	default:
