@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * stf-export.c : Structured Text Format Exporter (STF-E)
  *                Engine to construct CSV files
@@ -25,17 +24,18 @@
  */
 
 #include <gnumeric-config.h>
-#include "gnumeric.h"
-#include "gnm-i18n.h"
-#include "stf-export.h"
+#include <gnumeric.h>
+#include <gnm-i18n.h>
+#include <stf-export.h>
 
-#include "gnumeric-conf.h"
-#include "sheet.h"
-#include "workbook.h"
-#include "cell.h"
-#include "value.h"
-#include "gnm-format.h"
-#include "gnm-datetime.h"
+#include <gnumeric-conf.h>
+#include <sheet.h>
+#include <workbook.h>
+#include <cell.h>
+#include <value.h>
+#include <gutils.h>
+#include <gnm-format.h>
+#include <gnm-datetime.h>
 #include <gsf/gsf-output-iconv.h>
 #include <gsf/gsf-output-memory.h>
 #include <gsf/gsf-impl-utils.h>
@@ -44,7 +44,6 @@
 #include <string.h>
 #include <locale.h>
 
-
 struct _GnmStfExport {
 	GsfOutputCsv csv;
 
@@ -395,9 +394,8 @@ gnm_stf_export (GnmStfExport *stfe)
 /**
  * gnm_stf_export_can_transliterate:
  *
- * Return value: TRUE iff //TRANSLIT is supported
+ * Return value: %TRUE iff //TRANSLIT is supported
  **/
-
 gboolean
 gnm_stf_export_can_transliterate (void)
 {
@@ -596,9 +594,9 @@ GSF_CLASS (GnmStfExport, gnm_stf_export,
 /* ------------------------------------------------------------------------- */
 
 
-#include "wbc-gtk.h"
-#include "dialog-stf-export.h"
-#include "workbook-view.h"
+#include <wbc-gtk.h>
+#include <dialogs/dialog-stf-export.h>
+#include <workbook-view.h>
 
 /**
  * gnm_stf_get_stfe:
@@ -657,7 +655,8 @@ gnm_stf_get_stfe (GObject *obj)
 }
 
 static void
-gnm_stf_file_saver_save (G_GNUC_UNUSED GOFileSaver const *fs, GOIOContext *context,
+gnm_stf_file_saver_save (G_GNUC_UNUSED GOFileSaver const *fs,
+			 GOIOContext *context,
 			 GoView const *view, GsfOutput *output)
 {
 	WorkbookView *wbv = GNM_WORKBOOK_VIEW (view);
@@ -678,9 +677,14 @@ gnm_stf_file_saver_save (G_GNUC_UNUSED GOFileSaver const *fs, GOIOContext *conte
 	}
 
 	nosheets = (stfe->sheet_list == NULL);
-	if (nosheets)
-		gnm_stf_export_options_sheet_list_add
-			(stfe, wb_view_cur_sheet (wbv));
+	if (nosheets) {
+		GPtrArray *sel = gnm_file_saver_get_sheets (fs, wbv, TRUE);
+		unsigned ui;
+		for (ui = 0; ui < sel->len; ui++)
+			gnm_stf_export_options_sheet_list_add
+				(stfe, g_ptr_array_index (sel, ui));
+		g_ptr_array_unref (sel);
+	}
 
 	g_object_set (G_OBJECT (stfe), "sink", output, NULL);
 	if (gnm_stf_export (stfe) == FALSE)
@@ -696,26 +700,20 @@ gnm_stf_file_saver_save (G_GNUC_UNUSED GOFileSaver const *fs, GOIOContext *conte
 		gnm_stf_export_options_sheet_list_clear (stfe);
 }
 
+struct cb_set_export_option {
+	GOFileSaver *fs;
+	Workbook const *wb;
+};
+
 static gboolean
 cb_set_export_option (const char *key, const char *value,
-		      GError **err, gpointer user)
+		      GError **err, gpointer user_)
 {
-	Workbook *wb = user;
+	struct cb_set_export_option *user = user_;
+	Workbook const *wb = user->wb;
 	GnmStfExport *stfe = gnm_stf_get_stfe (G_OBJECT (wb));
 	const char *errtxt;
 
-	if (strcmp (key, "sheet") == 0) {
-		Sheet *sheet = workbook_sheet_by_name (wb, value);
-		if (!sheet) {
-			errtxt = _("There is no such sheet");
-			goto error;
-		}
-
-		gnm_stf_export_options_sheet_list_add (stfe, sheet);
-
-		return FALSE;
-	}
-
 	if (strcmp (key, "eol") == 0) {
 		const char *eol;
 		if (g_ascii_strcasecmp ("unix", value) == 0)
@@ -747,7 +745,9 @@ cb_set_export_option (const char *key, const char *value,
 			 err,
 			 (_("Invalid value for option %s: \"%s\"")));
 
-	errtxt = _("Invalid option for stf exporter");
+	return gnm_file_saver_common_export_option (user->fs, wb,
+						    key, value, err);
+
 error:
 	if (err)
 		*err = g_error_new (go_error_invalid (), 0, "%s", errtxt);
@@ -756,15 +756,18 @@ error:
 }
 
 static gboolean
-gnm_stf_fs_set_export_options (G_GNUC_UNUSED GOFileSaver *fs,
+gnm_stf_fs_set_export_options (GOFileSaver *fs,
 			       GODoc *doc,
 			       const char *options,
 			       GError **err,
 			       G_GNUC_UNUSED gpointer user)
 {
 	GnmStfExport *stfe = gnm_stf_get_stfe (G_OBJECT (doc));
+	struct cb_set_export_option data;
+	data.fs = fs;
+	data.wb = WORKBOOK (doc);
 	gnm_stf_export_options_sheet_list_clear (stfe);
-	return go_parse_key_value (options, err, cb_set_export_option, doc);
+	return go_parse_key_value (options, err, cb_set_export_option, &data);
 }
 
 /**
@@ -782,6 +785,7 @@ gnm_stf_file_saver_create (gchar const *id)
 					     GO_FILE_FL_WRITE_ONLY,
 					     gnm_stf_file_saver_save);
 	go_file_saver_set_save_scope (fs, GO_FILE_SAVE_WORKBOOK);
+	g_object_set (G_OBJECT (fs), "sheet-selection", TRUE, NULL);
 	g_signal_connect (G_OBJECT (fs), "set-export-options",
 			  G_CALLBACK (gnm_stf_fs_set_export_options),
 			  NULL);
