@@ -1241,7 +1241,7 @@ stf_cell_set_text (GnmCell *cell, char const *text)
 {
 	GnmExprTop const *texpr;
 	GnmValue *val;
-	GOFormat const *fmt = gnm_style_get_format (gnm_cell_get_style (cell));
+	GOFormat const *fmt = gnm_cell_get_format (cell);
 	const GODateConventions *date_conv = sheet_date_conv (cell->base.sheet);
 
 	if (!go_format_is_text (fmt) && *text == '=' && text[1] != 0) {
@@ -1386,6 +1386,7 @@ stf_parse_sheet (StfParseOptions_t *parseoptions,
 			if (text && *text) {
 				GnmCell *cell = sheet_cell_fetch (sheet, col, row);
 				if (!go_format_is_text (fmt) &&
+				    text[0] != '=' && text[0] != '\'' &&
 				    lcol < parseoptions->formats_decimal->len &&
 				    g_ptr_array_index (parseoptions->formats_decimal, lcol)) {
 					GOFormatFamily fam;
@@ -1398,7 +1399,6 @@ stf_parse_sheet (StfParseOptions_t *parseoptions,
 						v = value_new_string (text);
 					sheet_cell_set_value (cell, v);
 				} else {
-
 					stf_cell_set_text (cell, text);
 				}
 			}
@@ -1726,7 +1726,7 @@ stf_parse_options_guess_csv (char const *data)
 
 	res = stf_parse_options_new ();
 	stf_parse_options_set_type (res, PARSE_TYPE_CSV);
-	stf_parse_options_set_trim_spaces (res, TRIM_TYPE_LEFT | TRIM_TYPE_RIGHT);
+	stf_parse_options_set_trim_spaces (res, TRIM_TYPE_NEVER);
 	stf_parse_options_csv_set_indicator_2x_is_single (res, TRUE);
 	stf_parse_options_csv_set_duplicates (res, FALSE);
 	stf_parse_options_csv_set_trim_seps (res, FALSE);
@@ -1768,26 +1768,43 @@ stf_parse_options_guess_csv (char const *data)
 	if (quoteline) {
 		const char *p0 = my_utf8_strchr (quoteline, stringind);
 		const char *p = p0;
+		gboolean inquote;
 
 		if (gnm_debug_flag ("stf"))
 			g_printerr ("quoteline = [%s]\n", quoteline);
 
-		do {
-			p = g_utf8_next_char (p);
-		} while (*p && g_utf8_get_char (p) != stringind);
+		p = g_utf8_next_char (p);
+		inquote = TRUE;
+		while (inquote) {
+			gunichar c = g_utf8_get_char (p);
+			if (c == stringind) {
+				p = g_utf8_next_char (p);
+				if (g_utf8_get_char (p) == stringind)
+					p = g_utf8_next_char (p);
+				else
+					inquote = FALSE;
+			} else if (c == 0)
+				break;
+			else
+				p = g_utf8_next_char (p);
+		}
+
 		if (*p) p = g_utf8_next_char (p);
 		while (*p && g_unichar_isspace (g_utf8_get_char (p)))
 			p = g_utf8_next_char (p);
-		if (*p) {
+		if (*p && g_utf8_get_char (p) != stringind &&
+		    g_unichar_ispunct (g_utf8_get_char (p))) {
 			// Use the character after the quote.
-			if (g_unichar_ispunct (g_utf8_get_char (p)))
-				sep = g_strndup (p, g_utf8_next_char (p) - p);
+			sep = g_strndup (p, g_utf8_next_char (p) - p);
 		} else {
 			/* Try to use character before the quote.  */
 			while (p0 > quoteline && !sep) {
+				gunichar uc;
 				p = p0;
 				p0 = g_utf8_prev_char (p0);
-				if (!g_unichar_isspace (g_utf8_get_char (p0)))
+				uc = g_utf8_get_char (p0);
+				if (g_unichar_ispunct (uc) &&
+				    uc != stringind)
 					sep = g_strndup (p0, p - p0);
 			}
 		}
@@ -1986,8 +2003,9 @@ stf_parse_options_guess_formats (StfParseOptions_t *po, char const *data)
 			GPtrArray *line = g_ptr_array_index (lines, lno);
 			const char *data = col < line->len ? g_ptr_array_index (line, col) : "";
 			unsigned prev_possible = possible;
+			gunichar c0 = g_utf8_get_char (data);
 
-			if (*data == 0 || data[0] == '\'')
+			if (c0 == 0 || c0 == '\'' || c0 == '=')
 				continue;
 
 			do_check_date (data, STF_GUESS_DATE_DMY, FALSE, FALSE, &possible, date_conv);
