@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * analysis-exp-smoothing.c:
  *
@@ -21,24 +20,23 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
-#include "gnumeric.h"
-#include "analysis-exp-smoothing.h"
-#include "analysis-tools.h"
-#include "value.h"
-#include "ranges.h"
-#include "expr.h"
-#include "graph.h"
-#include "func.h"
-#include "numbers.h"
-#include "sheet-object-graph.h"
+#include <gnumeric.h>
+#include <tools/analysis-exp-smoothing.h>
+#include <tools/analysis-tools.h>
+#include <value.h>
+#include <ranges.h>
+#include <expr.h>
+#include <graph.h>
+#include <func.h>
+#include <numbers.h>
+#include <sheet-object-graph.h>
 #include <goffice/goffice.h>
-#include "sheet.h"
+#include <sheet.h>
 
 
 static GnmExpr const *
@@ -96,15 +94,15 @@ analysis_tool_exponential_smoothing_engine_ses_h_run (data_analysis_output_t *da
 
 	if (info->std_error_flag) {
 		fd_sqrt = gnm_func_lookup_or_add_placeholder ("SQRT");
-		gnm_func_ref (fd_sqrt);
+		gnm_func_inc_usage (fd_sqrt);
 		fd_sumxmy2 = gnm_func_lookup_or_add_placeholder ("SUMXMY2");
-		gnm_func_ref (fd_sumxmy2);
+		gnm_func_inc_usage (fd_sumxmy2);
 	}
 
 	fd_index = gnm_func_lookup_or_add_placeholder ("INDEX");
-	gnm_func_ref (fd_index);
+	gnm_func_inc_usage (fd_index);
 	fd_offset = gnm_func_lookup_or_add_placeholder ("OFFSET");
-	gnm_func_ref (fd_offset);
+	gnm_func_inc_usage (fd_offset);
 
 	if (info->show_graph)
 		create_line_plot (&plot, &so);
@@ -245,11 +243,11 @@ analysis_tool_exponential_smoothing_engine_ses_h_run (data_analysis_output_t *da
 
 	gnm_expr_free (expr_alpha);
 	if (fd_sqrt != NULL)
-		gnm_func_unref (fd_sqrt);
+		gnm_func_dec_usage (fd_sqrt);
 	if (fd_sumxmy2 != NULL)
-		gnm_func_unref (fd_sumxmy2);
-	gnm_func_unref (fd_offset);
-	gnm_func_unref (fd_index);
+		gnm_func_dec_usage (fd_sumxmy2);
+	gnm_func_dec_usage (fd_offset);
+	gnm_func_dec_usage (fd_index);
 
 	dao_redraw_respan (dao);
 
@@ -274,16 +272,16 @@ analysis_tool_exponential_smoothing_engine_ses_r_run (data_analysis_output_t *da
 
 	if (info->std_error_flag) {
 		fd_sqrt = gnm_func_lookup_or_add_placeholder ("SQRT");
-		gnm_func_ref (fd_sqrt);
+		gnm_func_inc_usage (fd_sqrt);
 		fd_sumxmy2 = gnm_func_lookup_or_add_placeholder ("SUMXMY2");
-		gnm_func_ref (fd_sumxmy2);
+		gnm_func_inc_usage (fd_sumxmy2);
 	}
 	fd_average = gnm_func_lookup_or_add_placeholder ("AVERAGE");
-	gnm_func_ref (fd_average);
+	gnm_func_inc_usage (fd_average);
 	fd_index = gnm_func_lookup_or_add_placeholder ("INDEX");
-	gnm_func_ref (fd_index);
+	gnm_func_inc_usage (fd_index);
 	fd_offset = gnm_func_lookup_or_add_placeholder ("OFFSET");
-	gnm_func_ref (fd_offset);
+	gnm_func_inc_usage (fd_offset);
 
 	if (info->show_graph)
 		create_line_plot (&plot, &so);
@@ -428,12 +426,12 @@ analysis_tool_exponential_smoothing_engine_ses_r_run (data_analysis_output_t *da
 
 	gnm_expr_free (expr_alpha);
 	if (fd_sqrt != NULL)
-		gnm_func_unref (fd_sqrt);
+		gnm_func_dec_usage (fd_sqrt);
 	if (fd_sumxmy2 != NULL)
-		gnm_func_unref (fd_sumxmy2);
-	gnm_func_unref (fd_average);
-	gnm_func_unref (fd_offset);
-	gnm_func_unref (fd_index);
+		gnm_func_dec_usage (fd_sumxmy2);
+	gnm_func_dec_usage (fd_average);
+	gnm_func_dec_usage (fd_offset);
+	gnm_func_dec_usage (fd_index);
 
 	dao_redraw_respan (dao);
 
@@ -459,17 +457,17 @@ analysis_tool_exponential_smoothing_engine_des_run (data_analysis_output_t *dao,
 
 	if (info->std_error_flag) {
 		fd_sqrt = gnm_func_lookup_or_add_placeholder ("SQRT");
-		gnm_func_ref (fd_sqrt);
+		gnm_func_inc_usage (fd_sqrt);
 		fd_sumxmy2 = gnm_func_lookup_or_add_placeholder ("SUMXMY2");
-		gnm_func_ref (fd_sumxmy2);
+		gnm_func_inc_usage (fd_sumxmy2);
 	}
 
 	fd_linest = gnm_func_lookup_or_add_placeholder ("LINEST");
-	gnm_func_ref (fd_linest);
+	gnm_func_inc_usage (fd_linest);
 	fd_index = gnm_func_lookup_or_add_placeholder ("INDEX");
-	gnm_func_ref (fd_index);
+	gnm_func_inc_usage (fd_index);
 	fd_offset = gnm_func_lookup_or_add_placeholder ("OFFSET");
-	gnm_func_ref (fd_offset);
+	gnm_func_inc_usage (fd_offset);
 
 	if (info->show_graph)
 		create_line_plot (&plot, &so);
@@ -661,12 +659,12 @@ analysis_tool_exponential_smoothing_engine_des_run (data_analysis_output_t *dao,
 	gnm_expr_free (expr_alpha);
 	gnm_expr_free (expr_gamma);
 	if (fd_sqrt != NULL)
-		gnm_func_unref (fd_sqrt);
+		gnm_func_dec_usage (fd_sqrt);
 	if (fd_sumxmy2 != NULL)
-		gnm_func_unref (fd_sumxmy2);
-	gnm_func_unref (fd_linest);
-	gnm_func_unref (fd_offset);
-	gnm_func_unref (fd_index);
+		gnm_func_dec_usage (fd_sumxmy2);
+	gnm_func_dec_usage (fd_linest);
+	gnm_func_dec_usage (fd_offset);
+	gnm_func_dec_usage (fd_index);
 
 	dao_redraw_respan (dao);
 
@@ -697,23 +695,23 @@ analysis_tool_exponential_smoothing_engine_ates_run (data_analysis_output_t *dao
 
 	if (info->std_error_flag) {
 		fd_sqrt = gnm_func_lookup_or_add_placeholder ("SQRT");
-		gnm_func_ref (fd_sqrt);
+		gnm_func_inc_usage (fd_sqrt);
 		fd_sumxmy2 = gnm_func_lookup_or_add_placeholder ("SUMXMY2");
-		gnm_func_ref (fd_sumxmy2);
+		gnm_func_inc_usage (fd_sumxmy2);
 	}
 
 	fd_linest = gnm_func_lookup_or_add_placeholder ("LINEST");
-	gnm_func_ref (fd_linest);
+	gnm_func_inc_usage (fd_linest);
 	fd_index = gnm_func_lookup_or_add_placeholder ("INDEX");
-	gnm_func_ref (fd_index);
+	gnm_func_inc_usage (fd_index);
 	fd_average = gnm_func_lookup_or_add_placeholder ("AVERAGE");
-	gnm_func_ref (fd_average);
+	gnm_func_inc_usage (fd_average);
 	fd_if = gnm_func_lookup_or_add_placeholder ("IF");
-	gnm_func_ref (fd_if);
+	gnm_func_inc_usage (fd_if);
 	fd_mod = gnm_func_lookup_or_add_placeholder ("mod");
-	gnm_func_ref (fd_mod);
+	gnm_func_inc_usage (fd_mod);
 	fd_row = gnm_func_lookup_or_add_placeholder ("row");
-	gnm_func_ref (fd_row);
+	gnm_func_inc_usage (fd_row);
 
 	if (info->show_graph)
 		create_line_plot (&plot, &so);
@@ -979,15 +977,15 @@ analysis_tool_exponential_smoothing_engine_ates_run (data_analysis_output_t *dao
 	gnm_expr_free (expr_gamma);
 	gnm_expr_free (expr_delta);
 	if (fd_sqrt != NULL)
-		gnm_func_unref (fd_sqrt);
+		gnm_func_dec_usage (fd_sqrt);
 	if (fd_sumxmy2 != NULL)
-		gnm_func_unref (fd_sumxmy2);
-	gnm_func_unref (fd_linest);
-	gnm_func_unref (fd_index);
-	gnm_func_unref (fd_average);
-	gnm_func_unref (fd_if);
-	gnm_func_unref (fd_mod);
-	gnm_func_unref (fd_row);
+		gnm_func_dec_usage (fd_sumxmy2);
+	gnm_func_dec_usage (fd_linest);
+	gnm_func_dec_usage (fd_index);
+	gnm_func_dec_usage (fd_average);
+	gnm_func_dec_usage (fd_if);
+	gnm_func_dec_usage (fd_mod);
+	gnm_func_dec_usage (fd_row);
 
 	dao_redraw_respan (dao);
 
@@ -1018,25 +1016,25 @@ analysis_tool_exponential_smoothing_engine_mtes_run (data_analysis_output_t *dao
 
 	if (info->std_error_flag) {
 		fd_sqrt = gnm_func_lookup_or_add_placeholder ("SQRT");
-		gnm_func_ref (fd_sqrt);
+		gnm_func_inc_usage (fd_sqrt);
 		fd_sumsq = gnm_func_lookup_or_add_placeholder ("SUMSQ");
-		gnm_func_ref (fd_sumsq);
+		gnm_func_inc_usage (fd_sumsq);
 	}
 
 	fd_linest = gnm_func_lookup_or_add_placeholder ("LINEST");
-	gnm_func_ref (fd_linest);
+	gnm_func_inc_usage (fd_linest);
 	fd_index = gnm_func_lookup_or_add_placeholder ("INDEX");
-	gnm_func_ref (fd_index);
+	gnm_func_inc_usage (fd_index);
 	fd_offset = gnm_func_lookup_or_add_placeholder ("OFFSET");
-	gnm_func_ref (fd_offset);
+	gnm_func_inc_usage (fd_offset);
 	fd_average = gnm_func_lookup_or_add_placeholder ("AVERAGE");
-	gnm_func_ref (fd_average);
+	gnm_func_inc_usage (fd_average);
 	fd_if = gnm_func_lookup_or_add_placeholder ("IF");
-	gnm_func_ref (fd_if);
+	gnm_func_inc_usage (fd_if);
 	fd_mod = gnm_func_lookup_or_add_placeholder ("mod");
-	gnm_func_ref (fd_mod);
+	gnm_func_inc_usage (fd_mod);
 	fd_row = gnm_func_lookup_or_add_placeholder ("row");
-	gnm_func_ref (fd_row);
+	gnm_func_inc_usage (fd_row);
 
 	if (info->show_graph)
 		create_line_plot (&plot, &so);
@@ -1354,16 +1352,16 @@ analysis_tool_exponential_smoothing_engine_mtes_run (data_analysis_output_t *dao
 	gnm_expr_free (expr_gamma);
 	gnm_expr_free (expr_delta);
 	if (fd_sqrt != NULL)
-		gnm_func_unref (fd_sqrt);
+		gnm_func_dec_usage (fd_sqrt);
 	if (fd_sumsq != NULL)
-		gnm_func_unref (fd_sumsq);
-	gnm_func_unref (fd_linest);
-	gnm_func_unref (fd_offset);
-	gnm_func_unref (fd_index);
-	gnm_func_unref (fd_average);
-	gnm_func_unref (fd_if);
-	gnm_func_unref (fd_mod);
-	gnm_func_unref (fd_row);
+		gnm_func_dec_usage (fd_sumsq);
+	gnm_func_dec_usage (fd_linest);
+	gnm_func_dec_usage (fd_offset);
+	gnm_func_dec_usage (fd_index);
+	gnm_func_dec_usage (fd_average);
+	gnm_func_dec_usage (fd_if);
+	gnm_func_dec_usage (fd_mod);
+	gnm_func_dec_usage (fd_row);
 
 	dao_redraw_respan (dao);
 
