@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * analysis-frequency.h:
  *
@@ -26,11 +25,11 @@
 #ifndef ANALYSIS_FREQUENCY_H
 #define ANALYSIS_FREQUENCY_H
 
-#include "gnumeric.h"
-#include "numbers.h"
-#include "dao.h"
-#include "tools.h"
-#include "analysis-tools.h"
+#include <gnumeric.h>
+#include <numbers.h>
+#include <tools/dao.h>
+#include <tools/tools.h>
+#include <tools/analysis-tools.h>
 
 typedef enum {
 	NO_CHART = 0,
