@@ -1,16 +1,15 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #ifndef _GNM_WBC_GTK_IMPL_H_
 # define _GNM_WBC_GTK_IMPL_H_
 
-#include "gnumeric.h"
-#include "wbc-gtk.h"
-#include "workbook-control-priv.h"
-#include "style.h"
-#include "widgets/gnumeric-expr-entry.h"
-#include "widgets/gnm-notebook.h"
+#include <gnumeric.h>
+#include <wbc-gtk.h>
+#include <workbook-control-priv.h>
+#include <style.h>
+#include <widgets/gnm-expr-entry.h>
+#include <widgets/gnm-notebook.h>
+#include <gui-util.h>
 
 #include <goffice/goffice.h>
-#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
@@ -164,9 +163,13 @@ void	 wbc_gtk_init_editline	(WBCGtk *wbcg);
 void	 wbc_gtk_init_actions	(WBCGtk *wbcg);
 void	 wbc_gtk_markup_changer	(WBCGtk *wbcg);
 
+void     wbcg_font_action_set_font_desc (GtkAction *act, PangoFontDescription *desc);
+
 gboolean wbc_gtk_load_templates (WBCGtk *gtk);
 
-G_MODULE_EXPORT void set_uifilename (char const *name, GtkActionEntry const *actions, int nb);
+GtkAction *wbcg_find_action (WBCGtk *wbcg, const char *name);
+
+G_MODULE_EXPORT void set_uifilename (char const *name, GnmActionEntry const *actions, int nb);
 
 G_END_DECLS
 
