@@ -16,8 +16,10 @@ GType       workbook_get_type            (void);
 Workbook   *workbook_new                 (void);
 Workbook   *workbook_new_with_sheets     (int sheet_count);
 
+void        workbook_mark_dirty          (Workbook *wb);
+
 /* Sheet support routines */
-GSList     *workbook_sheets              (Workbook const *wb);
+GPtrArray  *workbook_sheets              (Workbook const *wb);
 int         workbook_sheet_count         (Workbook const *wb);
 Sheet      *workbook_sheet_by_index	 (Workbook const *wb, int i);
 Sheet      *workbook_sheet_by_name       (Workbook const *wb, char const *sheet_name);
@@ -96,6 +98,9 @@ int workbook_sheet_state_size	(WorkbookSheetState const *wss);
 char *workbook_sheet_state_diff (WorkbookSheetState const *wss_a,
 				 WorkbookSheetState const *wss_b);
 
+// For bindings only!
+GSList *gnm_workbook_sheets0 (Workbook const *wb);
+
 #define WORKBOOK_FOREACH_SHEET(wb, sheet, code)				\
   do {									\
 	  const Workbook *wb_ = (wb);					\
