@@ -1,6 +1,8 @@
-#!/usr/bin/python
+#!/usr/bin/python3 -B
 # -----------------------------------------------------------------------------
 
+import GnumericTest
+
 import gi
 gi.require_version('Gnm', '1.12')
 from gi.repository import Gnm
